
dss
===


.. automodule:: opendssdirect.dss
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.dss.ActiveClass

    

.. function:: opendssdirect.dss.Basic

    

.. function:: opendssdirect.dss.Bus

    

.. function:: opendssdirect.dss.CapControls

    

.. function:: opendssdirect.dss.Capacitors

    

.. function:: opendssdirect.dss.Circuit

    

.. function:: opendssdirect.dss.CktElement

    

.. function:: opendssdirect.dss.Element

    

.. function:: opendssdirect.dss.Executive

    

.. function:: opendssdirect.dss.Fuses

    

.. function:: opendssdirect.dss.Generators

    

.. function:: opendssdirect.dss.Isource

    

.. function:: opendssdirect.dss.Lines

    

.. function:: opendssdirect.dss.LoadShape

    

.. function:: opendssdirect.dss.Loads

    

.. function:: opendssdirect.dss.Meters

    

.. function:: opendssdirect.dss.Monitors

    

.. function:: opendssdirect.dss.PDElements

    

.. function:: opendssdirect.dss.PVsystems

    

.. function:: opendssdirect.dss.Parser

    

.. function:: opendssdirect.dss.Properties

    

.. function:: opendssdirect.dss.Reclosers

    

.. function:: opendssdirect.dss.RegControls

    

.. function:: opendssdirect.dss.Relays

    

.. function:: opendssdirect.dss.Sensors

    

.. function:: opendssdirect.dss.Settings

    

.. function:: opendssdirect.dss.Solution

    

.. function:: opendssdirect.dss.SwtControls

    

.. function:: opendssdirect.dss.Topology

    

.. function:: opendssdirect.dss.Transformers

    

.. function:: opendssdirect.dss.Vsources

    

.. function:: opendssdirect.dss.XYCurves

    

.. function:: opendssdirect.dss.dss

    

.. function:: opendssdirect.dss.dss_lib

    An instance of this class represents a loaded dll/shared    library, exporting functions using the standard C calling    convention (named 'cdecl' on Windows).    The exported functions can be accessed as attributes, or by    indexing with the function name.  Examples:    <obj>.qsort -> callable object    <obj>['qsort'] -> callable object    Calling the functions releases the Python GIL during the call and    reacquires it afterwards.    

